Documentation
¶
Index ¶
- func FormatNRGBA(nrgba color.NRGBA) string
- func ParseNRGBA(str string) color.NRGBA
- type History
- func (this *History[T]) Clear()
- func (this *History[T]) Push(item T)
- func (this *History[T]) PushWeak(item T, minAge time.Duration)
- func (this *History[T]) Redo() T
- func (this *History[T]) Swap(item T)
- func (this *History[T]) SwapSilently(item T)
- func (this *History[T]) Top() T
- func (this *History[T]) Undo() T
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func FormatNRGBA ¶
FormatNRGBA formats an NRGBA value into a hex string.
Types ¶
type History ¶
type History[T comparable] struct { // contains filtered or unexported fields }
History stores a stack of items, always keeping the bottom-most one. It must be created using the NewHistory constructor, otherwise it will be invalid.
func NewHistory ¶
func NewHistory[T comparable](initial T, max int) *History[T]
NewHistory creates a new History. The initial item will be on the bottom, and it will remain there until the History overflows and chooses the item after it to be the initial item.
func (*History[T]) Clear ¶
func (this *History[T]) Clear()
Clear removes all items except for the initial one.
func (*History[T]) Push ¶
func (this *History[T]) Push(item T)
Push pushes a new item onto the stack. If the stack overflows (becomes bigger than the specified max value), the initial item is removed and the one on top of it takes its place.
func (*History[T]) PushWeak ¶
PushWeak replaces the most recent item if it was added recently (sooner than specified by minAge), and will otherwise push the item normally. If the history was popped or cleared beforehand, the item will always be pushed normally. This is intended to be used for things such as keystrokes.
func (*History[T]) Redo ¶
func (this *History[T]) Redo() T
Redo undoes an Undo operation and returns the resulting top of the stack.
func (*History[T]) Swap ¶
func (this *History[T]) Swap(item T)
Swap replaces the most recent item with another.
Source Files
¶
- color.go
- history.go